@@ -2,8 +2,8 @@ import requests
 
 from enum import Enum
 
-from urllib.parse import urljoin
-from urllib.parse import urlparse
+from requests.exceptions import ConnectionError
+from time import sleep
 
 from pydantic import BaseModel
 
@@ -33,15 +33,31 @@ class ComputeServer():
         }
 
     def get(self, endpoint: Endpoint, sub: str) -> requests.Response:
-        print(f"{self.endpoints[endpoint]}{sub}")
+        url = f"{self.endpoints[endpoint]}{sub}"
+        print(f"[GET] {url}")
         return requests.get(f"{self.endpoints[endpoint]}{sub}")
 
     def post(self, endpoint: Endpoint, sub: str, request: BaseModel = None) -> requests.Response:
         url = f"{self.endpoints[endpoint]}{sub}"
-        print(url)
+        retry = 1
+        sec = 3
+        while retry <= 3:
+            try:
+                if request is None:
+                    print(f"[POST] {url}")
+                    return requests.post(url)
+                print(f"[{type(request).__name__}] {url}")
+                return requests.post(url, json=request.json())
 
-        if request is None:
-            return requests.post(url)
-
-        return requests.post(url, json=request.json())
+            except ConnectionError as ce:
+                print(f"Connection refused by server. Retrying in {sec} seconds....")
+                sleep(sec)
+                retry += 1
+                sec *= retry
+            
+            except Exception as e:
+                print(f"Unknown error: {e}. Retrying in {sec} seconds....")
+                sleep(sec)
+                retry += 1
+                sec *= retry
 
